API docs for “spamfighter.core.message.message.MessageDomain”

# Class s.c.m.m.MessageDomain(object):

Part of spamfighter.core.message.message View Source View In Hierarchy

Список доменов атрибутов, которые должны быть у сообщения.

Такой объект хранится в домене.

Parameters | attrs | список доменов атрибутов (типов атрибутов)

Method | __init__ | Конструктор.
Method | names | Получить список имен доменов атрибутов.
Method | __getitem__ | Получить домен атрибута по имени.

def __init__(self, *args): (source)
Конструктор.

Parameters | *args | список доменов атрибутов, каждый `IAttributeDomain` (type: `list` )

def names(self): (source)
Получить список имен доменов атрибутов.

Returns | список имен (type: `list(str)` )

def __getitem__(self, key): (source)
Получить домен атрибута по имени.

Parameters | key | имя атрибута (type: `str` )
Returns | атрибут домена (type: `IAttributeDomain` )